==> elasticsearch-7.9.3-sources.jar: org/elasticsearch/search/aggregations/bucket/histogram/DateHistogramAggregationSupplier.java <==
/*
 * Licensed to Elasticsearch under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.search.aggregations.bucket.histogram;

import org.elasticsearch.common.Nullable;
import org.elasticsearch.common.Rounding;
import org.elasticsearch.search.aggregations.Aggregator;
import org.elasticsearch.search.aggregations.AggregatorFactories;
import org.elasticsearch.search.aggregations.BucketOrder;
import org.elasticsearch.search.aggregations.CardinalityUpperBound;
import org.elasticsearch.search.aggregations.support.AggregatorSupplier;
import org.elasticsearch.search.aggregations.support.ValuesSourceConfig;
import org.elasticsearch.search.internal.SearchContext;

import java.io.IOException;
import java.util.Map;

@FunctionalInterface
public interface DateHistogramAggregationSupplier extends AggregatorSupplier {
    Aggregator build(String name,
                     AggregatorFactories factories,
                     Rounding rounding,
                     Rounding.Prepared preparedRounding,
                     BucketOrder order,
                     boolean keyed,
                     long minDocCount,
                     @Nullable ExtendedBounds extendedBounds,
                     ValuesSourceConfig valuesSourceConfig,
                     SearchContext aggregationContext,
                     Aggregator parent,
                     CardinalityUpperBound cardinality,
                     Map<String, Object> metadata) throws IOException;
}

==> elasticsearch-7.10.2-sources.jar: org/elasticsearch/search/aggregations/bucket/histogram/DateHistogramAggregationSupplier.java <==
/*
 * Licensed to Elasticsearch under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.search.aggregations.bucket.histogram;

import org.elasticsearch.common.Nullable;
import org.elasticsearch.common.Rounding;
import org.elasticsearch.search.aggregations.Aggregator;
import org.elasticsearch.search.aggregations.AggregatorFactories;
import org.elasticsearch.search.aggregations.BucketOrder;
import org.elasticsearch.search.aggregations.CardinalityUpperBound;
import org.elasticsearch.search.aggregations.support.ValuesSourceConfig;
import org.elasticsearch.search.internal.SearchContext;

import java.io.IOException;
import java.util.Map;

@FunctionalInterface
public interface DateHistogramAggregationSupplier {
    Aggregator build(String name,
                     AggregatorFactories factories,
                     Rounding rounding,
                     Rounding.Prepared preparedRounding,
                     BucketOrder order,
                     boolean keyed,
                     long minDocCount,
                     @Nullable LongBounds extendedBounds,
                     @Nullable LongBounds hardBounds,
                     ValuesSourceConfig valuesSourceConfig,
                     SearchContext aggregationContext,
                     Aggregator parent,
                     CardinalityUpperBound cardinality,
                     Map<String, Object> metadata) throws IOException;
}
